@@ -8,13 +8,18 @@ import jsii
 import jsii.compat
 import publication
 
+import aws_cdk.aws_cloudwatch._jsii
+import aws_cdk.aws_iam._jsii
+import aws_cdk.aws_s3._jsii
+import aws_cdk.aws_s3_assets._jsii
 import aws_cdk.core._jsii
+import constructs._jsii
 
 __jsii_assembly__ = jsii.JSIIAssembly.load(
     "@aws-cdk/aws-synthetics",
-    "1.56.0",
+    "1.61.1",
     __name__[0:-6],
-    "aws-synthetics@1.56.0.jsii.tgz",
+    "aws-synthetics@1.61.1.jsii.tgz",
 )
 
 __all__ = [
